(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('direct-object')) :
  typeof define === 'function' && define.amd ? define(['direct-object'], factory) :
  (global.directObject = factory(global.directObject));
}(this, (function (directObject) { 'use strict';

  function GetJson(url) {
      return new Promise(function (resolve, reject) {
          var http = new XMLHttpRequest();
          http.onreadystatechange = function () {
              if (http.readyState === 4) {
                  var data = {};
                  if (http.status === 200 && http.responseText) {
                      try {
                          data = JSON.parse(http.responseText);
                      }
                      catch (e) {
                          reject(e);
                      }
                      resolve(data);
                  }
                  else {
                      reject(new Error('404'));
                  }
              }
          };
          http.open('get', url);
          http.send();
      });
  }
  function FormatTranslations(rawTranslations) {
      var flat = directObject.DirectTree.Flat(rawTranslations, '.');
      return directObject.DirectMap.DoubleMap(flat, function (value, key) { return ({
          key: key.endsWith('..') ? key.substr(0, key.length - 2) : key,
          value: value
      }); });
  }
  function LoadTranslations(locale, localePath) {
      var languageFile = localePath + "/" + locale + ".json";
      return GetJson(languageFile);
  }
  function CreateModule(path) {
      var LOCALE_PATH = path;
      var state = {
          locale: '',
          translations: {}
      };
      var mutations = {
          SET: function (state, locale) {
              state.locale = locale;
          },
          SET_TRANSLATIONS: function (state, translations) {
              state.translations = translations;
          }
      };
      var actions = {
          SET: function (_a, locale) {
              var commit = _a.commit;
              LoadTranslations(locale, LOCALE_PATH).then(function (data) {
                  commit('SET', locale);
                  commit('SET_TRANSLATIONS', FormatTranslations(data));
              });
          }
      };
      return {
          namespaced: true,
          state: state,
          mutations: mutations,
          actions: actions
      };
  }

  var VueDynamicLocale = {
      install: function (vue, options) {
          if (options) {
              var store = options.store, path = options.path, _a = options.defaultLocale, defaultLocale = _a === void 0 ? 'en' : _a;
              store.registerModule('locale', CreateModule(path));
              store.dispatch('locale/SET', defaultLocale);
              vue.prototype.$setLocale = function (locale) {
                  this.$store.dispatch('locale/SET', locale);
              };
              vue.mixin({
                  computed: {
                      $t: function () {
                          return this.$store.state.locale.translations;
                      }
                  }
              });
          }
      }
  };

  return VueDynamicLocale;

})));
//# sourceMappingURL=vue-dynamic-locale.umd.js.map
